# pastax

**P**arameterizable **A**uto-differentiable **S**imulators of ocean **T**rajectories in j**AX**.

## Installation

`pastax` is Pip-installable:

```shell
pip install pastax
```

## Usage

Documentation is under construction.
Meanwhile, see the [minimal demonstration notebook](docs/demo.ipynb) and the [full API documentation](https://pastax.readthedocs.io/en/latest/api/).

## Contributing

Contributions are welcomed!
See [CONTRIBUTING.md](https://github.com/vadmbertr/pastax/blob/main/CONDUCT.md) and [CONDUCT.md](https://github.com/vadmbertr/pastax/blob/main/CONDUCT.md) to get started.
